# frozen_string_literal: true

class WorkoutsController < ApplicationController
  before_action :set_workout, only: %i[show edit update destroy]

  def index
    @workouts = Workout.all
  end

  def show; end

  def new
    @workout = Workout.new
    @workout.elements.new
  end

  def create
    result = CreateWorkout.result(
      safe_params: workout_params,
      add_element: params[:add_element],
      remove_element: params[:remove_element]
    )

    @workout = result.workout

    if result.success?
      redirect_to @workout, notice: 'Workout was successfully created.'
    else
      render :new, status: :unprocessable_entity
    end
  end

  def update
    result = UpdateWorkout.result(
      workout: @workout,
      safe_params: workout_params,
      add_element: params[:add_element],
      remove_element: params[:remove_element]
    )

    @workout = result.workout

    if result.success?
      redirect_to @workout, notice: 'Workout was successfully updated.'
    else
      render :edit, status: :unprocessable_entity
    end
  end

  private

  def set_workout
    @workout = Workout.find(params[:id])
  end

  def workout_params
    params.require(:workout).permit(
      :name,
      :rounds,
      :repetition_scheme,
      elements_attributes: %i[id repetitions time distance movement_id weights _destroy]
    )
  end
end
