# frozen_string_literal: true

class PerformanceDecorator < ApplicationDecorator
  delegate_all

  def description
    case measure.to_sym
    when :completion
      "#{movement.name}, #{sets} x #{repetitions} reps @ #{weight} kg"
    when :distance
      "#{time / 60} min #{movement.name}: #{distance / 1000} km"
    when :time
      "#{(distance / 1000).to_i}K #{movement.name}: #{formatted_duration(time)} min"
    when :weight
      "#{movement.name}, #{sets} x #{repetitions} reps @ #{weights.join('/')} kg"
    else
      raise
    end
  end

  private

  def formatted_duration(time)
    duration = ActiveSupport::Duration.build(time)

    [
      duration.parts[:minutes],
      duration.parts[:seconds].to_s.rjust(2, '0')
    ].join(':')
  end
end
