# frozen_string_literal: true

class WorkoutDecorator < ApplicationDecorator
  delegate_all

  decorates_association :elements

  def description
    return measure if repetition_scheme.blank?

    "#{repetition_scheme} reps of #{measure}"
  end

  def repetition_scheme
    return '' if object.repetition_scheme.blank? | object.repetition_scheme.empty?

    object.repetition_scheme.map(&:to_s).join('-')
  end

  def measure
    case object.measure.to_sym
    when :completion
      "#{sets} x #{elements.map(&:description).join}"
    when :time
      "#{elements.map(&:description).join(', ')} for time"
    when :distance
      "#{elements.map(&:description).join(', ')} for max distance"
    when :weight
      "#{elements.map(&:description).join(', ')} for max weight"
    else
      raise "unknown measure #{measure}"
    end
  end
end
