# frozen_string_literal: true

class WorkoutElementDecorator < ApplicationDecorator
  delegate_all

  def description
    x = [repetitions, time, distance, name]

    x << "@ #{weights}" if object.weights

    x.join(' ').strip.gsub(/\s+/, ' ')
  end

  def name
    movement.name.downcase.pluralize([object.repetitions.to_i, object.workout.repetition_scheme.sum, 1].max)
  end

  def repetitions
    return nil unless object.repetitions

    object.repetitions.to_s
  end

  def distance
    return nil unless object.distance

    "#{object.distance.to_i} m"
  end

  def time
    return nil unless object.time

    if (object.time % 60).zero? && object.time > 90
      "#{object.time / 60} min"
    else
      "#{object.time} s"
    end
  end

  def weights
    return if object.weights.blank?

    values = object.weights.map do |val|
      (val % 1).zero? ? val.to_i : val.to_f
    end

    "#{values.join('/')} kg"
  end
end
