# frozen_string_literal: true

class Performance < ApplicationRecord
  extend Enumerize

  # ASSOCIATIONS
  belongs_to :user
  belongs_to :movement, optional: true

  # ATTRIBUTES
  store_attribute :details, :sets, :integer, default: 1
  store_attribute :details, :repetitions, :integer
  store_attribute :details, :time, :integer # seconds
  store_attribute :details, :distance, :decimal, { precision: 8, scale: 2 } # meters
  store_attribute :details, :measure, :string

  enumerize :measure, in: %i[time distance weight completion]

  # VALIDATIONS
  validates :measure, presence: true

  # INSTANCE METHODS
  def weight
    weights.max
  end

  def weight=(value)
    self.weights = [value]
  end

  def volume
    x = if weights.any?
          weights.inject(0) { |sum, w| sum + w * repetitions }
        else
          distance
        end

    x *= sets if sets && sets > weights.size

    x.to_i
  end
end
