# frozen_string_literal: true

class Workout < ApplicationRecord
  extend Enumerize

  # ASSOCIATIONS
  has_many :elements, -> { order(position: :asc) }, class_name: 'WorkoutElement',
                                                    inverse_of: :workout,
                                                    dependent: :destroy
  accepts_nested_attributes_for :elements, allow_destroy: true

  has_many :movements, through: :elements

  # ATTRIBUTES
  enumerize :frequency, in: %i[continuous pause_between_sets start_every], predicates: true

  enumerize :measure, in: %i[completion distance repetitions time weight]
  attribute :measure, default: :completion

  alias_attribute :sets, :rounds

  # VALIDATIONS
  validates :interval, numericality: { greater_than: 0 }, allow_blank: true

  # SETTERS
  def repetition_scheme=(value)
    value = case value
            when String
              value.scan(/\d+/)
            else
              Array(value)
            end

    super value
  end

  # INSTANCE METHODS
  def emom?
    start_every? && interval == 60
  end
end
