# frozen_string_literal: true

class WorkoutElement < ApplicationRecord
  # ASSOCIATIONS
  belongs_to :workout
  belongs_to :movement

  acts_as_list scope: :workout, top_of_list: 0

  # ATTRIBUTES
  store_attribute :details, :repetitions, :integer
  store_attribute :details, :weights, :json
  store_attribute :details, :time, :integer # seconds
  store_attribute :details, :distance, :decimal, { precision: 8, scale: 2 } # meters

  # VALIDATIONS
  validates :workout, presence: true
  validates :movement, presence: true

  # SETTERS
  def weights=(value)
    value = case value
            when String
              # Input can be _anything_. Try to make sense of it.
              value.gsub(',', '.').scan(/\d+\.?\d*/).map(&:to_f)
            else
              Array(value)
            end

    super value
  end
end
