# frozen_string_literal: true

require 'test_helper'

class CreateWorkoutTest < ActiveSupport::TestCase
  setup do
    @result = nil
  end

  test 'creates workout with elements' do
    air_squat = create(:movement, name: 'Air squat')
    push_up = create(:movement, name: 'Push-up')

    safe_params = {
      rounds: '',
      elements_attributes: {
        '0' => { movement_id: air_squat.id, weights: '70/50' },
        '1' => { movement_id: push_up.id }
      }
    }

    assert_changes 'Workout.count' do
      @result = CreateWorkout.result(
        safe_params: safe_params,
        add_element: nil,
        remove_element: nil
      )
    end

    assert @result.success?

    assert_equal air_squat, @result.workout.movements.first
    assert_equal push_up, @result.workout.movements.second
  end

  test 'requires movement_id for elements' do
    safe_params = {
      rounds: '',
      elements_attributes: {
        '0' => { movement_id: '' }
      }
    }

    assert_no_changes 'Workout.count' do
      @result = CreateWorkout.result(
        safe_params: safe_params,
        add_element: nil,
        remove_element: nil
      )
    end

    assert @result.failure?
    assert_includes @result.workout.errors.messages.keys, :'elements.movement'

    assert 2, @result.workout.elements.size
  end

  test 'should add element' do
    air_squat = create(:movement, name: 'Air squat')

    safe_params = {
      rounds: '',
      elements_attributes: {
        '0' => { movement_id: air_squat.id }
      }
    }

    assert_no_changes 'Workout.count' do
      @result = CreateWorkout.result(
        safe_params: safe_params,
        add_element: 'Any value will do',
        remove_element: nil
      )
    end

    assert @result.failure?
    assert_equal I18n.t(:element_added), @result.error

    assert 2, @result.workout.elements.size
  end

  test 'should remove element' do
    air_squat = create(:movement, name: 'Air squat')
    push_up = create(:movement, name: 'Push-up')

    safe_params = {
      rounds: '',
      elements_attributes: {
        '0' => { movement_id: air_squat.id },
        '1' => { movement_id: push_up.id }
      }
    }

    assert_no_changes 'Workout.count' do
      @result = CreateWorkout.result(
        safe_params: safe_params,
        add_element: nil,
        remove_element: '1'
      )
    end

    assert @result.failure?
    assert_equal I18n.t(:element_removed), @result.error

    assert 1, @result.workout.elements.size
  end
end
