# frozen_string_literal: true

require 'test_helper'

module  WorkoutsControllerTest
  class CommonTest < ActionDispatch::IntegrationTest
    setup do
      sign_in users(:melli)
    end

    private

    def safe_params
      ActionController::Parameters.new(@params).require(:workout).permit(
        :name,
        :rounds,
        elements_attributes: %i[id repetitions movement_id weights _destroy]
      )
    end
  end

  class IndexTest < CommonTest
    setup do
      Workout.create
    end

    test 'should get index' do
      get workouts_url
      assert_response :success
    end
  end

  class UpdateTest < CommonTest
    setup do
      @workout = Workout.create
      @params = { workout: @workout.attributes }
    end

    test '#update calls CreateWorkout actor with correct params' do
      expected_params = {
        workout: @workout,
        safe_params: safe_params,
        add_element: nil,
        remove_element: nil
      }

      actor = Minitest::Mock.new
      actor.expect :call, ServiceActor::Result.new(workout: @workout, failure?: false), [nil, expected_params]

      UpdateWorkout.stub :call, actor do
        patch workout_url(@workout), params: @params
      end

      assert_mock actor
    end

    test 'successful #update redirects to #show' do
      actor = Minitest::Mock.new
      actor.expect :call, ServiceActor::Result.new(workout: @workout, failure?: false), [nil, Hash]

      UpdateWorkout.stub :call, actor do
        patch workout_url(@workout), params: @params
      end

      assert_redirected_to(proc { workout_url(@workout) })
    end

    test 'unsuccessful #update renders :edit' do
      actor = Minitest::Mock.new
      actor.expect :call, ServiceActor::Result.new(workout: @workout, failure?: true), [nil, Hash]

      UpdateWorkout.stub :call, actor do
        patch workout_url(@workout), params: @params
      end

      assert_response 422
    end
  end

  class CreateTest < CommonTest
    setup do
      @workout = Workout.new(id: 5)
      @params = { workout: @workout.attributes, add_element: 'YES', remove_element: '23' }
    end

    test '#create calls CreateWorkout actor with correct params' do
      expected_params = {
        safe_params: safe_params,
        add_element: 'YES',
        remove_element: '23'
      }

      actor = Minitest::Mock.new
      actor.expect :call, ServiceActor::Result.new(workout: @workout, failure?: false), [nil, expected_params]

      CreateWorkout.stub :call, actor do
        post workouts_url, params: @params
      end

      assert_mock actor
    end

    test 'successful #create redirects to #show' do
      actor = Minitest::Mock.new
      actor.expect :call, ServiceActor::Result.new(workout: @workout, failure?: false), [nil, Hash]

      CreateWorkout.stub :call, actor do
        post workouts_url, params: @params
      end

      assert_redirected_to(proc { workout_url(@workout) })
    end

    test 'unsuccessful #create renders :new' do
      actor = Minitest::Mock.new
      actor.expect :call, ServiceActor::Result.new(workout: @workout, failure?: true), [nil, Hash]

      CreateWorkout.stub :call, actor do
        post workouts_url, params: @params
      end

      assert_response 422
    end
  end
end
