# frozen_string_literal: true

require 'test_helper'

class PerformanceDecoratorTest < Draper::TestCase
  def decorator
    ::PerformanceDecorator.new(@performance)
  end

  test '#description for 12 min run' do
    @performance = build(
      :performance,
      movement: build(:movement, name: 'Run'),
      time: 720,
      distance: 2489.0,
      measure: :distance
    )

    assert_equal '12 min Run: 2.489 km', decorator.description
  end

  test '#description for 5K run' do
    @performance = build(
      :performance,
      movement: build(:movement, name: 'Run'),
      distance: 5000.0,
      time: 1501,
      measure: :time
    )

    assert_equal '5K Run: 25:01 min', decorator.description
  end

  test "#description for 10' KB EMOM" do
    @performance = build(
      :performance,
      movement: build(:movement, name: 'Kettlebell swing'),
      sets: 10,
      repetitions: 12,
      weight: 24.0,
      measure: :completion
    )

    assert_equal 'Kettlebell swing, 10 x 12 reps @ 24.0 kg', decorator.description
  end

  test '#description for 3RM Back squat' do
    @performance = build(
      :performance,
      movement: build(:movement, name: 'Back squat'),
      repetitions: 3,
      weight: 112.5,
      measure: :weight
    )

    assert_equal 'Back squat, 1 x 3 reps @ 112.5 kg', decorator.description
  end

  test '#description for 10 sets of 7 front squats' do
    @performance = build(
      :performance,
      movement: build(:movement, name: 'Front squat'),
      sets: 5,
      repetitions: 7,
      weights: [70],
      measure: :completion
    )

    assert_equal 'Front squat, 5 x 7 reps @ 70.0 kg', decorator.description
  end

  test '#description for 5 sets of 7 front squats, increase weight' do
    @performance = build(
      :performance,
      movement: build(:movement, name: 'Front squat'),
      sets: 3,
      repetitions: 7,
      weights: [70, 72.5, 75],
      measure: :weight
    )

    assert_equal 'Front squat, 3 x 7 reps @ 70.0/72.5/75.0 kg', decorator.description
  end
end
