# frozen_string_literal: true

require 'test_helper'

class WorkoutDecoratorTest < Draper::TestCase
  def decorator
    ::WorkoutDecorator.new(@workout)
  end

  test '#description for 12 min run' do
    @workout = build(:workout, :cooper_test)

    assert_equal '12 min run for max distance', decorator.description
  end

  test '#description for 5K run' do
    @workout = build(
      :workout,
      measure: :time,
      elements: [
        build(:workout_element, movement_name: 'Run', distance: 5000)
      ]
    )

    assert_equal '5000 m run for time', decorator.description
  end

  test '#description Karen' do
    @workout = build(
      :workout,
      measure: :time,
      elements: [
        build(:workout_element, movement_name: 'Wall ball', repetitions: 150)
      ]
    )

    assert_equal '150 wall balls for time', decorator.description
  end

  test "#description for 10' KB EMOM" do
    @workout = build(
      :workout,
      measure: :completion,
      sets: 10,
      elements: [
        build(:workout_element, movement_name: 'Kettlebell swing', repetitions: 12, weights: [24])
      ]
    )

    assert_equal '10 x 12 kettlebell swings @ 24 kg', decorator.description
  end

  test '#description for 3RM Back squat' do
    @workout = build(
      :workout,
      measure: :weight,
      elements: [
        build(:workout_element, movement_name: 'Back squat', repetitions: 3)
      ]
    )

    assert_equal '3 back squats for max weight', decorator.description
  end

  test '#description for Fran' do
    @workout = build(:workout, :fran)

    assert_equal '21-15-9 reps of pull-ups, thrusters @ 43.1/29.5 kg for time', decorator.description
  end

  test '#repetition_scheme' do
    @workout = Workout.new(repetition_scheme: '')
    assert_equal '', decorator.repetition_scheme

    @workout.repetition_scheme = [21, 15, 9]
    assert_equal '21-15-9', decorator.repetition_scheme
  end
end
