# frozen_string_literal: true

require 'test_helper'

class MovementTest < ActiveSupport::TestCase
  def setup
    @movement = FactoryBot.build(:movement)
  end

  test 'can save the factory build' do
    assert @movement.save
  end

  ### ASSOCIATIONS
  def test_has_many_distinct_workouts
    workout = FactoryBot.create(:workout)

    workout.elements << FactoryBot.create(:workout_element, movement: @movement)
    workout.elements << FactoryBot.create(:workout_element, movement: @movement)

    assert_equal 1, @movement.workouts.count
  end

  def test_cannot_destroy_movement_with_associated_workout
    workout = FactoryBot.create(:workout)

    workout.elements << FactoryBot.create(:workout_element, movement: @movement)

    assert_not @movement.destroy
  end

  ### ATTRIBUTES
  test 'requires name' do
    @movement.name = nil

    assert_not @movement.valid?
    assert_includes @movement.errors, :name

    @movement.name = 'Mountain climber'

    assert @movement.valid?
  end

  test 'requires unique name' do
    FactoryBot.create(:movement, name: 'Back squat')

    @movement.update(name: 'Back squat')

    assert_not @movement.valid?
    assert_includes @movement.errors, :name
  end

  test 'requires unique abbreviation' do
    FactoryBot.create(:movement, abbreviation: 'BSQ')

    @movement.update(abbreviation: 'BSQ')

    assert_not @movement.valid?
    assert_includes @movement.errors, :abbreviation
  end

  test 'allows blank abbreviation' do
    @movement.abbreviation = ''

    assert @movement.valid?
  end
end
