# frozen_string_literal: true

require 'test_helper'

class PerformanceTest < ActiveSupport::TestCase
  def setup
    @performance = FactoryBot.build(:performance)
  end

  test 'can save the factory build' do
    assert @performance.save
  end

  ### ASSOCIATIONS
  test 'has a user' do
    assert @performance.user.present?
    refute @performance.update(user: nil)
  end

  test 'has an (optional) movement' do
    assert_nil @performance.movement

    movement = FactoryBot.build(:movement)

    assert @performance.update(movement: movement)
  end

  ### ATTRIBUTES
  # sets, rounds
  # repetitions, minutes, seconds, calories, meters, ft, calories
  # kg, lbs, cm, m
  # weight, length, time, distance

  test 'attributes' do
    assert_respond_to @performance, :sets, 'Does not respond to #sets'
    assert_respond_to @performance, :measure, 'Does not respond to #measure'
  end

  ### VALIDATIONS
  test 'validates presence of :measure' do
    refute @performance.update(measure: nil)
  end

  ### EXAMPLES
  test '10 min KB EMOM' do
    @performance = FactoryBot.build(
      :performance,
      movement: FactoryBot.build(:movement, name: 'Kettlebell swing'),
      sets: 10,
      repetitions: 12, # 6/6!! ?
      weights: [24.0]
    )

    assert @performance.save
  end

  test '12 min run' do
    @performance = build(
      :performance,
      movement: FactoryBot.build(:movement, name: 'Run'),
      time: 1200,
      distance: 2489.0
    )

    assert @performance.save
  end

  ### INSTANCE METHODS
  test '#volume for KB EMOM' do
    @performance.sets = 10
    @performance.repetitions = 12
    @performance.weight = 24.0

    assert_equal 10 * 12 * 24, @performance.volume
  end

  test '#volume for 12 min run' do
    @performance.distance = 2000

    assert_equal 2000, @performance.volume

    @performance.sets = 2

    assert_equal 4000, @performance.volume
  end

  test '#volume for 3 sets of 5 BSQ with ascending weights' do
    @performance.sets = 3
    @performance.repetitions = 5
    @performance.weights = [80, 90, 100]

    assert_equal 5 * 80 + 5 * 90 + 5 * 100, @performance.volume
  end
end
