# frozen_string_literal: true

require 'test_helper'

class WorkoutElementTest < ActiveSupport::TestCase
  def setup
    @workout_element = @element = FactoryBot.build(:workout_element)
  end

  test 'can save factory build' do
    assert @element.save
  end

  test 'can pass movement name as transient attribute' do 
    @element = FactoryBot.build(:workout_element, movement_name: 'Run')

    assert_equal 'Run', @element.movement.name
  end

  ### ASSOCIATIONS
  test 'belongs to workout (required)' do
    @element.workout = nil
    @element.valid?

    assert_includes @element.errors, :workout
  end

  test 'belongs to movement (required)' do
    @element.movement = nil
    @element.valid?

    assert_includes @element.errors, :movement
  end

  ### ATTRIBUTES
  test 'has repetitions (optional)' do
    @element.repetitions = 5

    assert_equal 5, @element.repetitions
  end

  test 'can write and read array of weights' do
    @element.weights = [95, 65]

    assert_equal [95.000, 65.000], @element.weights
  end

  test 'can write and read any format of weights' do
    [
      # INPUT       EXPECTED
      [[72.5, 50],  [72.500, 50.000]],
      ['72,5 50.0', [72.500, 50.000]],
      ['0.83',      [0.830]],
      ['40/30,5/20',  [40.000, 30.500, 20.000]]
    ].each do |input, expected|
      @element.weights = input

      assert_equal expected, @element.weights
    end
  end
end
